@@ -30,7 +30,6 @@ final class WP_Site {
 	 * A numeric string, for compatibility reasons.
 	 *
 	 * @since 4.5.0
-	 * @access public
 	 * @var string
 	 */
 	public $blog_id;
@@ -39,7 +38,6 @@ final class WP_Site {
 	 * Domain of the site.
 	 *
 	 * @since 4.5.0
-	 * @access public
 	 * @var string
 	 */
 	public $domain = '';
@@ -48,7 +46,6 @@ final class WP_Site {
 	 * Path of the site.
 	 *
 	 * @since 4.5.0
-	 * @access public
 	 * @var string
 	 */
 	public $path = '';
@@ -62,7 +59,6 @@ final class WP_Site {
 	 * A numeric string, for compatibility reasons.
 	 *
 	 * @since 4.5.0
-	 * @access public
 	 * @var string
 	 */
 	public $site_id = '0';
@@ -71,7 +67,6 @@ final class WP_Site {
 	 * The date on which the site was created or registered.
 	 *
 	 * @since 4.5.0
-	 * @access public
 	 * @var string Date in MySQL's datetime format.
 	 */
 	public $registered = '0000-00-00 00:00:00';
@@ -80,7 +75,6 @@ final class WP_Site {
 	 * The date and time on which site settings were last updated.
 	 *
 	 * @since 4.5.0
-	 * @access public
 	 * @var string Date in MySQL's datetime format.
 	 */
 	public $last_updated = '0000-00-00 00:00:00';
@@ -91,7 +85,6 @@ final class WP_Site {
 	 * A numeric string, for compatibility reasons.
 	 *
 	 * @since 4.5.0
-	 * @access public
 	 * @var string
 	 */
 	public $public = '1';
@@ -102,7 +95,6 @@ final class WP_Site {
 	 * A numeric string, for compatibility reasons.
 	 *
 	 * @since 4.5.0
-	 * @access public
 	 * @var string
 	 */
 	public $archived = '0';
@@ -116,7 +108,6 @@ final class WP_Site {
 	 * A numeric string, for compatibility reasons.
 	 *
 	 * @since 4.5.0
-	 * @access public
 	 * @var string
 	 */
 	public $mature = '0';
@@ -127,7 +118,6 @@ final class WP_Site {
 	 * A numeric string, for compatibility reasons.
 	 *
 	 * @since 4.5.0
-	 * @access public
 	 * @var string
 	 */
 	public $spam = '0';
@@ -138,7 +128,6 @@ final class WP_Site {
 	 * A numeric string, for compatibility reasons.
 	 *
 	 * @since 4.5.0
-	 * @access public
 	 * @var string
 	 */
 	public $deleted = '0';
@@ -149,7 +138,6 @@ final class WP_Site {
 	 * A numeric string, for compatibility reasons.
 	 *
 	 * @since 4.5.0
-	 * @access public
 	 * @var string
 	 */
 	public $lang_id = '0';
@@ -157,9 +145,7 @@ final class WP_Site {
 	/**
 	 * Retrieves a site from the database by its ID.
 	 *
-	 * @static
 	 * @since 4.5.0
-	 * @access public
 	 *
 	 * @global wpdb $wpdb WordPress database abstraction object.
 	 *
@@ -196,12 +182,11 @@ final class WP_Site {
 	 * default properties based on that information.
 	 *
 	 * @since 4.5.0
-	 * @access public
 	 *
 	 * @param WP_Site|object $site A site object.
 	 */
 	public function __construct( $site ) {
-		foreach( get_object_vars( $site ) as $key => $value ) {
+		foreach ( get_object_vars( $site ) as $key => $value ) {
 			$this->$key = $value;
 		}
 	}
@@ -210,7 +195,6 @@ final class WP_Site {
 	 * Converts an object to array.
 	 *
 	 * @since 4.6.0
-	 * @access public
 	 *
 	 * @return array Object as array.
 	 */
@@ -225,7 +209,6 @@ final class WP_Site {
 	 * Allows access to extended site properties.
 	 *
 	 * @since 4.6.0
-	 * @access public
 	 *
 	 * @param string $key Property to get.
 	 * @return mixed Value of the property. Null if not available.
@@ -240,11 +223,15 @@ final class WP_Site {
 			case 'siteurl':
 			case 'post_count':
 			case 'home':
+			default: // Custom properties added by 'site_details' filter.
 				if ( ! did_action( 'ms_loaded' ) ) {
 					return null;
 				}
+
 				$details = $this->get_details();
-				return $details->$key;
+				if ( isset( $details->$key ) ) {
+					return $details->$key;
+				}
 		}
 
 		return null;
@@ -257,7 +244,6 @@ final class WP_Site {
 	 * Checks for extended site properties.
 	 *
 	 * @since 4.6.0
-	 * @access public
 	 *
 	 * @param string $key Property to check if set.
 	 * @return bool Whether the property is set.
@@ -275,6 +261,15 @@ final class WP_Site {
 					return false;
 				}
 				return true;
+			default: // Custom properties added by 'site_details' filter.
+				if ( ! did_action( 'ms_loaded' ) ) {
+					return false;
+				}
+
+				$details = $this->get_details();
+				if ( isset( $details->$key ) ) {
+					return true;
+				}
 		}
 
 		return false;
@@ -286,7 +281,6 @@ final class WP_Site {
 	 * Allows current multisite naming conventions while setting properties.
 	 *
 	 * @since 4.6.0
-	 * @access public
 	 *
 	 * @param string $key   Property to set.
 	 * @param mixed  $value Value to assign to the property.
@@ -310,7 +304,6 @@ final class WP_Site {
 	 * This method is used internally to lazy-load the extended properties of a site.
 	 *
 	 * @since 4.6.0
-	 * @access private
 	 *
 	 * @see WP_Site::__get()
 	 *
@@ -322,7 +315,7 @@ final class WP_Site {
 		if ( false === $details ) {
 
 			switch_to_blog( $this->blog_id );
-			// Create a raw copy of the object for backwards compatibility with the filter below.
+			// Create a raw copy of the object for backward compatibility with the filter below.
 			$details = new stdClass();
 			foreach ( get_object_vars( $this ) as $key => $value ) {
 				$details->$key = $value;
@@ -333,17 +326,7 @@ final class WP_Site {
 			$details->home       = get_option( 'home' );
 			restore_current_blog();
 
-			$cache_details = true;
-			foreach ( array( 'blogname', 'siteurl', 'post_count', 'home' ) as $field ) {
-				if ( false === $details->$field ) {
-					$cache_details = false;
-					break;
-				}
-			}
-
-			if ( $cache_details ) {
-				wp_cache_set( $this->blog_id, $details, 'site-details' );
-			}
+			wp_cache_set( $this->blog_id, $details, 'site-details' );
 		}
 
 		/** This filter is documented in wp-includes/ms-blogs.php */
